@@ -390,11 +390,16 @@ namespace Oxygen
 
             case LM_ButtonWidth:
             case LM_ButtonHeight:
-            case LM_TitleHeight:
             {
                 return buttonSize;
             }
 
+            case LM_TitleHeight:
+            {
+                const int titleHeight = QFontMetrics(options()->font(true)).height();
+                return qMax(buttonSize, titleHeight);
+            }
+
             case LM_ButtonSpacing:
             return narrowSpacing ? 1:3;
 
@@ -615,7 +620,7 @@ namespace Oxygen
             int offset = layoutMetric( LM_OuterPaddingTop );
 
             // radial gradient positionning
-            const int height = hideTitleBar() ? 0:buttonSize();
+            const int height = hideTitleBar() ? 0:layoutMetric(LM_TitleHeight);
             if( isMaximized() ) offset -= 3;
 
             const QWidget* window( isPreview() ? this->widget() : widget->window() );
@@ -633,7 +638,7 @@ namespace Oxygen
             int offset = layoutMetric( LM_OuterPaddingTop );
 
             // radial gradient positionning
-            const int height = hideTitleBar() ? 0:buttonSize();
+            const int height = hideTitleBar() ? 0:layoutMetric(LM_TitleHeight);
             if( isMaximized() ) offset -= 3;
 
             // background pixmap
@@ -1450,8 +1455,10 @@ namespace Oxygen
             else mask.translate( -layoutMetric( LM_OuterPaddingLeft ), -layoutMetric( LM_OuterPaddingTop ) );
 
             // only return non-empty region on the sides for which there is no border
-            if( configuration()->frameBorder() == Configuration::BorderNone ) return QRegion( rect.adjusted( -3, 0, 3, 3 ) ) - mask;
-            else if( configuration()->frameBorder() == Configuration::BorderNoSide ) return QRegion( rect.adjusted( -3, 0, 3, 0 ) ) - mask;
+            enum { extendedBorderSize = 3 };
+
+            if( configuration()->frameBorder() == Configuration::BorderNone ) return QRegion( rect.adjusted( -extendedBorderSize, 0, extendedBorderSize, extendedBorderSize ) ) - mask;
+            else if( configuration()->frameBorder() == Configuration::BorderNoSide ) return QRegion( rect.adjusted( -extendedBorderSize, 0, extendedBorderSize, 0 ) ) - mask;
             else if( !compositingActive() ) return QRegion( rect ) - mask;
 
         }
